@@ -1,4 +1,4 @@
-/***             analog 5.02             http://www.analog.cx/             ***/
+/***             analog 5.03             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -14,7 +14,7 @@
 
 /*** OS specific things ***/
 
-#define VNUMBER "5.02"    /* the version number of this program */
+#define VNUMBER "5.03"    /* the version number of this program */
 
 #undef VERSION /* If no OS set, compilation will fail by not knowing VERSION */
 
@@ -500,20 +500,22 @@ enum {ITEM_VHOST, ITEM_FILE, ITEM_USER, ITEM_REFERRER, ITEM_BROWSER, ITEM_HOST,
 #define ITEM_NUMBER (INP_CODE)
 #define INPUT_NUMBER (INP_YEAR)  /* NB There is INP_NUMBER and INPUT_NUMBER */
 
-/* Types of report: must have date reports then GENSUM then other reports,
-   finishing with dervreps, then SIZE, CODE, PROCTIME in some order. */
+/* Types of report. They must be in the following order: date Reports;
+   date Summaries; GENSUM; general reports; dervreps; arrayreps.
+   (The order is insignificant within each section.) */
 /* See also repcodes, anchorname and repname in globals.c */
 /* Also report descriptions files have these entries in this order */
-enum {REP_YEAR, REP_QUARTERLY, REP_MONTH, REP_WEEK, REP_DAYREP, REP_DAYSUM,
-      REP_HOURREP, REP_HOURSUM, REP_WEEKHOUR, REP_QUARTERREP, REP_QUARTERSUM,
-      REP_FIVEREP, REP_FIVESUM, REP_GENSUM, REP_REQ, REP_REDIR, REP_FAIL,
+enum {REP_YEAR, REP_QUARTERLY, REP_MONTH, REP_WEEK, REP_DAYREP, REP_HOURREP,
+      REP_QUARTERREP, REP_FIVEREP, REP_DAYSUM, REP_HOURSUM, REP_WEEKHOUR,
+      REP_QUARTERSUM, REP_FIVESUM, REP_GENSUM, REP_REQ, REP_REDIR, REP_FAIL,
       REP_TYPE, REP_DIR, REP_HOST, REP_REDIRHOST, REP_FAILHOST, REP_DOM,
       REP_REF, REP_REFSITE, REP_REDIRREF, REP_FAILREF, REP_BROWREP, REP_VHOST,
       REP_REDIRVHOST, REP_FAILVHOST, REP_USER, REP_REDIRUSER, REP_FAILUSER,
       REP_ORG, REP_SEARCHREP, REP_SEARCHSUM, REP_INTSEARCHREP,
       REP_INTSEARCHSUM, REP_BROWSUM, REP_OS, REP_SIZE, REP_CODE, REP_PROCTIME,
       REP_NUMBER};
-#define DATEREP_NUMBER (REP_GENSUM)
+#define DATEREPORTS_NUMBER (REP_DAYSUM)   /* just the eight "Reports" */
+#define DATEREP_NUMBER (REP_GENSUM)   /* including the five "Summaries" too */
 #define FIRST_GENREP (REP_GENSUM + 1)
 #define GENREP_NUMBER (REP_NUMBER - FIRST_GENREP)
 #define FIRST_DERVREP (REP_SEARCHREP)
@@ -572,7 +574,7 @@ enum {ARMENIAN, /*BOSNIAN,*/ BULGARIAN, BULGARIAN_MIK, CATALAN,
       JAPANESE_SJIS, JAPANESE_UTF, KOREAN, LATVIAN, /*LITHUANIAN,*/
       NORWEGIAN, NYNORSK, POLISH, PORTUGUESE, BR_PORTUGUESE,
       /*ROMANIAN, RUSSIAN,*/ SERBIAN, /*SLOVAK,*/ SLOVENE, SLOVENE_1250,
-      /*SPANISH,*/ SWEDISH, SWEDISH_ALT, TURKISH, UKRAINIAN};
+      SPANISH, SWEDISH, SWEDISH_ALT, TURKISH, UKRAINIAN};
 
 /* lngstrs; charset_ must be first */
 enum {charset_, weekbeg_, year_, quarteryr_, month_, day_, days_, hr_, minute_,
@@ -837,9 +839,9 @@ typedef struct {
   choice reporder[REP_NUMBER + 1];
   logical repq[REP_NUMBER], last7, runtime;
   choice cols[REP_NUMBER][COL_NUMBER];
-  unsigned int rows[DATEREP_NUMBER];
+  unsigned int rows[DATEREPORTS_NUMBER];
   char graph[DATEREP_NUMBER];
-  logical back[DATEREP_NUMBER];
+  logical back[DATEREPORTS_NUMBER];
   choice chartby[GENREP_NUMBER];
   logical jpegcharts, pngimages;
   choice sortby[GENREP_NUMBER], subsortby[GENREP_NUMBER];
