@@ -1,4 +1,4 @@
-/***             analog 5.02             http://www.analog.cx/             ***/
+/***             analog 5.03             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -108,17 +108,17 @@ char *country[] = {"am", /*"ba",*/ "bg", "bgm", "cat", /*"cn",*/ "tw",
 		   /*"hr",*/ "cz", "cz1", "dk", "nl", "uk", "us", /*"fi",*/
 		   "fr", "de", /*"gr",*/ "hu", /*"is",*/ "it", "jpe", "jpj",
 		   "jps", "jpu", "kr", "lv", /*"lt",*/ "no", "no2", "pl", "pt",
-		   "br", /*"ro", "ru",*/ "yu", /*"sk",*/ "si", "si1", /*"es",*/
+		   "br", /*"ro", "ru",*/ "yu", /*"sk",*/ "si", "si1", "es",
 		   "se", "se2", "tr", "ua"};
 /* Report code letters in order of enum in anlghea3.h */
 /* Any new ones must also be added to reportorder in anlghea2.h */
-char repcodes[] = "1QmWDdHhw4657xrEItiSlLofskKBvRMujJZNnYybpzcP";
+char repcodes[] = "1QmWDH45dhw67xrEItiSlLofskKBvRMujJZNnYybpzcP";
 /* Names for the anchors within the report, in the same order */
 /* At most eight letters, because we use them as filenames too. (This limit is
    assumed in piechart()). */
-char *anchorname[] = {"year", "quartly", "month", "week", "dayrep", "daysum",
-		      "hourrep", "hoursum", "weekhour", "quartrep", "quartsum",
-		      "five", "fivesum", "gensum", "req", "redir", "fail",
+char *anchorname[] = {"year", "quartly", "month", "week", "dayrep", "hourrep",
+		      "quartrep", "fiverep",  "daysum", "hoursum", "weekhour",
+		      "quartsum", "fivesum", "gensum", "req", "redir", "fail",
 		      "type", "dir", "host", "redihost", "failhost", "dom",
 		      "ref", "refsite", "redirref", "failref", "browrep",
 		      "vhost", "redirvh", "failvh", "user", "rediuser",
@@ -127,10 +127,10 @@ char *anchorname[] = {"year", "quartly", "month", "week", "dayrep", "daysum",
 /* These report names are in English, so not the same as in langfile */
 /* Again in order of enum in anlghea3.h */
 char *repname[] = {"Yearly Report", "Quarterly Report", "Monthly Report",
-		   "Weekly Report", "Daily Report", "Daily Summary",
-		   "Hourly Report", "Hourly Summary",
-		   "Hour of the Week Summary", "Quarter-Hour Report",
-		   "Quarter-Hour Summary", "Five-Minute Report",
+		   "Weekly Report", "Daily Report", "Hourly Report",
+		   "Quarter-Hour Report", "Five-Minute Report",
+		   "Daily Summary", "Hourly Summary",
+		   "Hour of the Week Summary", "Quarter-Hour Summary",
 		   "Five-Minute Summary", "General Summary", "Request Report",
 		   "Redirection Report", "Failure Report", "File Type Report",
 		   "Directory Report", "Host Report",
@@ -1361,7 +1361,7 @@ void globals(char *comname) {
   rep2colhead[REP_INTSEARCHREP] = search_;
   rep2colhead[REP_INTSEARCHSUM] = search_;
   rep2colhead[REP_CODE] = code_;
-  rep2busystr = (unsigned int *)xmalloc(DATEREP_NUMBER * sizeof(unsigned int));
+  rep2busystr = (unsigned int *)xmalloc(DATEREPORTS_NUMBER * sizeof(unsigned int));
   rep2busystr[REP_DAYREP] = busyday_;
   rep2busystr[REP_HOURREP] = busyhour_;
   rep2busystr[REP_QUARTERREP] = busyquarterhr_;
@@ -1509,6 +1509,7 @@ void defaults(Options *op) {
   op->outopts.searchconv = SEARCHCHARCONVERT;
   op->outopts.outstyle = OUTPUT;
   op->outopts.html = TRUE;
+  htmlstrlen = &htmlstrlen_normal;
   DEFAULTSTR(op->outopts.headerfile, HEADERFILE);
   DEFAULTSTR(op->outopts.footerfile, FOOTERFILE);
   DEFAULTSTR(op->outopts.outfile, OUTFILE);
