@@ -1,4 +1,4 @@
-/***             analog 5.02             http://www.analog.cx/             ***/
+/***             analog 5.03             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -333,12 +333,6 @@ void correct(Options *op) {
     }
     od->pagewidth = od->latexpagewidth;
   }
-  for (i = 0, j = 0, k = 0; i < DATEREP_NUMBER; i++) {
-    if (i != REP_DAYSUM && i != REP_HOURSUM) {
-      j += (int)(od->repq[i] && od->back[i]);
-      k += (int)(od->repq[i]);
-    }
-  }
   for (lastincp = NULL, incp = op->argshead, templ = FALSE; incp != NULL;
        TO_NEXT(incp)) {
     if (STREQ((char *)(incp->name), "pages")) {
@@ -367,6 +361,10 @@ void correct(Options *op) {
     else
       lastincp = incp;
   }
+  for (i = 0, j = 0, k = 0; i < DATEREPORTS_NUMBER; i++) {
+    j += (int)(od->repq[i] && od->back[i]);
+    k += (int)(od->repq[i]);
+  }
   if (j != 0 && j != k)
     warn('D', TRUE, "Time reports have not all got same value of BACK");
   /* The next bit is totally foul, so here's a guide. Numbers are repeated
@@ -991,12 +989,11 @@ void finalinit(Options *op) {
 	(lngstr[charset_])++;
 	od->html = FALSE;
       }
+      /* htmlstrlen already set to htmlstrlen_normal in defaults() */
       if (strcaseeq(lngstr[charset_], "UTF-8"))
 	htmlstrlen = &htmlstrlen_utf8;
       else if (strcaseeq(lngstr[charset_], "ISO-2022-JP"))
 	htmlstrlen = &htmlstrlen_jis;
-      else
-	htmlstrlen = &htmlstrlen_normal;
       for (i = 0; i < 7; i++)
 	DEFAULTSTR(od->dayname[i], nextlngstr(tempf, od->lang.file, TRUE));
       for (i = 0; i < 12; i++)
