@@ -1,4 +1,4 @@
-/***             analog 5.02             http://www.analog.cx/             ***/
+/***             analog 5.03             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -348,7 +348,7 @@ void configall(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
 }
 
 void configallback(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
-  logical *q = (logical *)opt;   /* same as configall(), but only DATEREPs */
+  logical *q = (logical *)opt;  /* same as configall(), but only DATEREPORTs */
   int i;
   logical result;
 
@@ -367,7 +367,7 @@ void configallback(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
     badwarn(cmd, TRUE, arg1, arg2, rc);
     return;
   }
-  for (i = 0; i < DATEREP_NUMBER; i++)
+  for (i = 0; i < DATEREPORTS_NUMBER; i++)
     q[i] = result;
 }
 
@@ -577,7 +577,7 @@ void configlang(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
 	   strcaseeq(arg1, "SLOVENIAN-1250"))
     lang->code = SLOVENE_1250;
   else if (strcaseeq(arg1, "SPANISH"))
-    /* lang->code = SPANISH; */ oldlang = TRUE;
+    lang->code = SPANISH;
   else if (strcaseeq(arg1, "SWEDISH"))
     lang->code = SWEDISH;
   else if (strcaseeq(arg1, "SWEDISH-ALT"))
