@@ -1,4 +1,4 @@
-/***             analog 5.02             http://www.analog.cx/             ***/
+/***             analog 5.03             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -499,6 +499,7 @@ char *datesprintf(Outchoices *od, char *fmt, datecode_t date, unsigned int hr,
   }
   code2date(date, &d, &m, &y);
   code2date(newdate, &d2, &m2, &y2);
+  ENSURE_LEN(ans, len, 1);  /* in case fmt is "" */
   for (c = fmt, s = ans; *c != '\0'; c++) {
     current = (ans == NULL)?0:(size_t)(s - ans);
     ENSURE_LEN(ans, len, current + increment);
@@ -606,7 +607,7 @@ char *datesprintf(Outchoices *od, char *fmt, datecode_t date, unsigned int hr,
     }    /* if *c == '%' */
     else
       PUTc(s, *c);
-  }
+  }  /* for c */
   *s = '\0';
   return(ans);
 }
