@@ -1,4 +1,4 @@
-/***             analog 5.02             http://www.analog.cx/             ***/
+/***             analog 5.03             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2001 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -625,11 +625,13 @@ void report_sep(char c, char *type) {
 
 void report_daterep(Outchoices *od, choice j) {
   report_cols(od->cols[j]);
-  printf("    Maximum number of rows: ");
-  if (od->rows[j] == 0)
-    printf("unlimited\n");
-  else
-    printf("%u\n", od->rows[j]);
+  if (j < DATEREPORTS_NUMBER) {
+    printf("    Maximum number of rows: ");
+    if (od->rows[j] == 0)
+      printf("unlimited\n");
+    else
+      printf("%u\n", od->rows[j]);
+  }
   printf("    Graphing by ");
   if (od->graph[j] == 'R' || od->graph[j] == 'r')
     printf("requests\n");
@@ -637,8 +639,9 @@ void report_daterep(Outchoices *od, choice j) {
     printf("requests for pages\n");
   else
     printf("bytes\n");
-  printf("    Displaying %s dates at top\n",
-	 (od->back[j])?"latest":"earliest");
+  if (j < DATEREPORTS_NUMBER)
+    printf("    Displaying %s dates at top\n",
+	   (od->back[j])?"latest":"earliest");
 }
 
 void report_genrep(Outchoices *od, choice j) {
